@@ -68,15 +68,39 @@ typedef struct
 } gpa_keygen_para_t;
 
 
+/* An object to collect information about key imports.  */
+struct gpa_import_result_s
+{
+  unsigned int files;     /* # of files imported.  */
+  unsigned int bad_files; /* # of files with errors.  */
+
+  /* To avoid breaking translated strings the variables below are int
+     and not unsigned int as they should be for counters.  */
+  int considered;
+  int imported;
+  int unchanged;
+  int secret_read;
+  int secret_imported;
+  int secret_unchanged;
+};
+typedef struct gpa_import_result_s *gpa_import_result_t;
+
+
+
 /* Report an unexpected error in GPGME and quit the application.
    Better to use the macro instead of the function.  */
 #define gpa_gpgme_error(err) \
          do { _gpa_gpgme_error (err, __FILE__, __LINE__); } while (0)
-void _gpa_gpgme_error (gpg_error_t err, const char *file, int line);
+void _gpa_gpgme_error (gpg_error_t err,
+                       const char *file, int line) G_GNUC_NORETURN;
 
 /* The same as gpa_gpgme_error, without quitting.  */
-void gpa_gpgme_warning_ext (gpg_error_t err, const char *desc);
-void gpa_gpgme_warning (gpg_error_t err);
+#define gpa_gpgme_warning_ext(err,desc) \
+         do { _gpa_gpgme_warning (err, desc, __FILE__, __LINE__); } while (0)
+#define gpa_gpgme_warning(err) \
+         do { _gpa_gpgme_warning (err, NULL, __FILE__, __LINE__); } while (0)
+void _gpa_gpgme_warning (gpg_error_t err, const char *desc,
+                         const char *file, int line);
 
 /* Initialize a gpgme_ctx_t for use with GPA.  */
 gpgme_ctx_t gpa_gpgme_new (void);
@@ -112,13 +136,8 @@ int gpa_open_output (const char *filename, gpgme_data_t *data,
 int gpa_open_input (const char *filename, gpgme_data_t *data,
 		    GtkWidget *parent);
 
-#ifdef G_OS_WIN32
-/* Convert newlines.  */
-void dos_to_unix (gchar *str, gsize *len);
-#endif
-
 /* Write the contents of the gpgme_data_t into the clipboard.  */
-void dump_data_to_clipboard (gpgme_data_t data, GtkClipboard *clipboard);
+int dump_data_to_clipboard (gpgme_data_t data, GtkClipboard *clipboard);
 
 /* Begin generation of a key with the given parameters.  It prepares
    the parameters required by Gpgme and returns whatever
@@ -127,9 +146,10 @@ gpg_error_t gpa_generate_key_start (gpgme_ctx_t ctx,
 				    gpa_keygen_para_t *params);
 
 /* Backup a key.  It exports both the public and secret keys to a
-   file.  Returns TRUE on success and FALSE on error.  It displays
-   errors to the user.  */
-gboolean gpa_backup_key (const gchar *fpr, const char *filename);
+   file.  IS_X509 tells the function that the fingerprint is from an
+   X.509 key.  Returns TRUE on success and FALSE on error.  It
+   displays errors to the user.  */
+gboolean gpa_backup_key (const gchar *fpr, const char *filename, int is_x509);
 
 gpa_keygen_para_t *gpa_keygen_para_new (void);
 
@@ -141,6 +161,16 @@ const gchar *gpa_key_ownertrust_string (gpgme_key_t key);
 /* Key validity strings.  */
 const gchar *gpa_key_validity_string (gpgme_key_t key);
 
+/* Function to manage import results.  */
+void gpa_gpgme_update_import_results (gpa_import_result_t result,
+                                      unsigned int files,
+                                      unsigned int bad_files,
+                                      gpgme_import_result_t info);
+void gpa_gpgme_show_import_results (GtkWidget *parent,
+                                    gpa_import_result_t result);
+
+
+
 /* This is the function called by GPGME when it wants a
    passphrase.  */
 gpg_error_t gpa_passphrase_cb (void *hook, const char *uid_hint,
@@ -209,6 +239,7 @@ gpg_error_t gpa_start_simple_gpg_command (gboolean (*cb)
                                           (void *opaque, char *line),
                                           void *cb_arg,
                                           gpgme_protocol_t protocol,
+                                          int use_stderr,
                                           const char *first_arg, ...
                                           ) G_GNUC_NULL_TERMINATED;
 
